package com.zaojiao.http

sealed class HttpResult {
    data class Success<T>(
        val data: T,
    ) : HttpResult()

    data class Failure(
        val throwable: Throwable,
    ) : HttpResult()
}

inline fun <T> HttpResult.onSuccess(callback: (T) -> Unit): HttpResult {
    if (this is HttpResult.Success<*>) {
        callback(data as T)
    }

    return this
}

inline fun HttpResult.onFailure(callback: (Throwable) -> Unit): HttpResult {
    if (this is HttpResult.Failure) {
        callback(throwable)
    }

    return this
}